wait_for_callback

Function wait_for_callback 

pub async fn wait_for_callback(port: u16) -> Result<OAuthCallback, OAuthError>
Start a local callback server to capture the OAuth authorization code and state

Listens on the specified port and waits for the OAuth redirect. Returns the authorization code and state (CSRF token) from the callback URL.